/*
    SPDX-FileCopyrightText: 2009 Igor Trindade Oliveira <igor_trindade@yahoo.com.br>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include "test.h"

class TestVCard : public Test
{
public:
    explicit TestVCard(const QString &dir);
};
